getStartPosition method

  1. @override
Future<LatLong?> getStartPosition()

Returns the recommended start position for this map file.

If a start position is defined in the map header, it is returned. Otherwise, the center of the map's bounding box is returned. Requires _lateOpen to have been completed.

Implementation

@override
Future<LatLong?> getStartPosition() async {
  await _lateOpen();
  if (null != getMapHeaderInfo().startPosition) {
    return getMapHeaderInfo().startPosition;
  }
  return getMapHeaderInfo().boundingBox.getCenterPoint();
}