restrictToZoomRange method

void restrictToZoomRange(
  1. int minZoom,
  2. int maxZoom
)

Restricts the zoom levels for which this datastore will provide data.

This is useful when combining multiple map files in a MultiMapDatabase to ensure that each map is only used for its intended zoom range.

Implementation

void restrictToZoomRange(int minZoom, int maxZoom) {
  zoomlevelRange = ZoomlevelRange(minZoom, maxZoom);
  _zoomlevelOverridden = true;
}