SIGNATURE_LENGTH_POI property
Length of the debug signature at the beginning of each POI.
Implementation
static final int SIGNATURE_LENGTH_POI = 32;
Length of the debug signature at the beginning of each POI.
static final int SIGNATURE_LENGTH_POI = 32;