SIGNATURE_LENGTH_WAY property
Length of the debug signature at the beginning of each way.
Implementation
static final int SIGNATURE_LENGTH_WAY = 32;
Length of the debug signature at the beginning of each way.
static final int SIGNATURE_LENGTH_WAY = 32;