IWayholderCollection class abstract

Implementers

Constructors

IWayholderCollection()

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Wayholder wayholder) → void
addAll(Iterable<Wayholder> wayholders) → void
dispose() Future<void>
forEach(void action(Wayholder wayholder)) Future<void>
freeRessources() Future<void>
Frees resources that cannot be transferred to an isolate.
nodeCount() Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathCount() Future<int>
removeWhere(bool test(Wayholder wayholder)) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited