freeRessources abstract method
Frees resources that cannot be transferred to an isolate.
This is typically called before sending the ReadbufferSource to another isolate.
Implementation
Future<void> freeRessources();
Frees resources that cannot be transferred to an isolate.
This is typically called before sending the ReadbufferSource to another isolate.
Future<void> freeRessources();