IsolateSubfileFiller class

An isolate-based wrapper for SubfileFiller to perform way preparation in the background.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareWays(IWayholderCollection wayholderCollection) Future<List<Wayholder>>
Prepares a list of ways by filtering and simplifying them.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required ZoomlevelRange subfileZoomlevelRange, required BoundingBox boundingBox, required double maxDeviation}) Future<IsolateSubfileFiller>
createInstance(IsolateInitInstanceParams<SubfileFillerInstanceRequest> object) Future<void>
readBlobDataStatic(IWayholderCollection wayholderCollection) Future<Object?>