PoiWayCollections class

///////////////////////////////////////////////////////////////////////////

Constructors

PoiWayCollections()

Properties

hashCode int
The hash code for this object.
no setterinherited
poiholderCollections Map<int, IPoiholderCollection>
minimum zoomlevel for all corresponding pois
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wayholderCollections Map<int, IWayholderCollection>
minimum zoomlevel for all corresponding ways
final

Methods

clear() Future<void>
freeRessources() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited