Poiholder class

A data holder for a single Point of Interest (POI) during the map file writing process.

This class encapsulates a PointOfInterest and uses the TagholderMixin to manage the analysis and serialization of its tags.

Constructors

Poiholder({required ILatLong position, required TagholderCollection tagholderCollection})

Properties

hashCode int
The hash code for this object.
no setterinherited
latitude double
The latitude of this point in degrees.
no setter
longitude double
The longitude of this point in degrees.
no setter
position → ILatLong
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagholderCollection TagholderCollection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toStringWithoutNames() String

Operators

operator ==(Object other) bool
The equality operator.
inherited