SubfileFiller class

/////////////////////////////////////////////////////////////////////////// A class that prepares way data before it is added to a sub-file.

This involves two main steps:

  1. Filtering: Removing ways that are too small to be visually significant at the target zoom level.
  2. Simplification: Reducing the number of vertices in the remaining ways to optimize storage and rendering performance.
Implemented types

Constructors

SubfileFiller(ZoomlevelRange subfileZoomlevelRange, double maxDeviation, BoundingBox boundingBox)

Properties

boundingBox → BoundingBox
final
hashCode int
The hash code for this object.
no setterinherited
maxDeviation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simplifyFilter WaySimplifyFilter
getter/setter pair
sizeFilter WaySizeFilter
getter/setter pair
subfileZoomlevelRange → ZoomlevelRange
final
wayCropper WayCropper
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareWays(IWayholderCollection wayholderCollection) Future<List<Wayholder>>
Prepares a list of ways by filtering and simplifying them.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited