SubfileFillerInstanceRequest class

///////////////////////////////////////////////////////////////////////////

Constructors

SubfileFillerInstanceRequest({required ZoomlevelRange subfileZoomlevelRange, required BoundingBox boundingBox, required double maxDeviation})

Properties

boundingBox → BoundingBox
final
hashCode int
The hash code for this object.
no setterinherited
maxDeviation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subfileZoomlevelRange → ZoomlevelRange
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited