WaySizeFilter class
A filter that removes ways that are too small to be visually significant at a given zoom level.
This is an important optimization to avoid processing and rendering ways that would only cover a few pixels on the screen. The size threshold is defined in pixels and converted to a geographical distance.
Constructors
- WaySizeFilter(int zoomlevel, double filterSizePixels)
Properties
- filterSizePixels → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDeviationLatLong ↔ double?
-
getter/setter pair
- projection → PixelProjection
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
filter(
Wayholder wayholder) → Wayholder? -
Filters the ways within a
wayholder, removing any that are smaller than the configured pixel size. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited