HolderCollectionFactory class
Constructors
- HolderCollectionFactory()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPoiholderCollection(
String prefix) → IPoiholderCollection -
createWayholderCollection(
String prefix) → IWayholderCollection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setImplementation(
HolderCollectionImplementation implementation) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited