PoiholderCollection class
A helper class to hold all POIs for a specific zoom level during the sub-file creation process.
- Implemented types
Constructors
Properties
Methods
-
add(
Poiholder poiholder) → void -
override
-
addAll(
Iterable< Poiholder> poiholders) → void -
override
-
addPoidata(
ILatLong latlong, TagholderCollection tagholderCollection) → void -
dispose(
) → Future< void> -
override
-
forEach(
void action(Poiholder poiholder)) → Future< void> -
override
-
freeRessources(
) → Future< void> -
override
-
getAll(
) → Future< Iterable< Poiholder> > -
override
-
mergeFrom(
IPoiholderCollection other) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeWhere(
bool test(Poiholder poiholder)) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited