Subfile class
A class responsible for creating a single sub-file within a Mapsforge map file.
This involves collecting all POIs and ways for a given zoom level range, processing them into tiles, and writing the tile index and tile data.
Constructors
- Subfile({required int baseZoomLevel, required ZoomlevelRange zoomlevelRange, required MapHeaderInfo mapHeaderInfo, required PoiWayCollections poiWayCollections, required TagholderModel model})
Properties
- baseZoomLevel → int
-
Base zoom level of the sub-file, which equals to one block.
final
- filter → BoundaryFilter
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapHeaderInfo → MapHeaderInfo
-
final
- model → TagholderModel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tileCount → int
-
no setter
- zoomlevelRange → ZoomlevelRange
-
final
Methods
-
createTileWriters(
int currentTileY, int instanceCount, bool debugFile, List< String> languagesPreferences) → Future<List< ITileWriter> > -
dispose(
) → void -
getTilesLength(
bool debugFile) → Future< int> - Calculates the total length of all tile data in this sub-file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareTiles(
bool debugFile, int instanceCount) → Future< void> - Prepares all tiles for this sub-file by processing the POIs and ways in parallel isolates.
-
statistics(
) → Future< void> - Logs statistics about the contents of this sub-file.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTileIndex(
bool debugFile) → Writebuffer - Writes the tile index for this sub-file to a Writebuffer.
-
writeTiles(
bool debugFile, SinkWithCounter ioSink) → Future< void> -
Writes all tile data for this sub-file to the given
ioSink.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited