Wayholder class
Holds one way and its tags
Constructors
- Wayholder({required TagholderCollection tagholderCollection})
Properties
- boundingBoxCached → BoundingBox
-
no setter
-
closedOutersRead
→ List<
Waypath> -
no setter
-
closedOutersWrite
→ List<
Waypath> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
innerRead
→ List<
Waypath> -
no setter
-
innerWrite
→ List<
Waypath> -
no setter
- labelPosition ↔ ILatLong?
-
The position of the area label (may be null). Only relations can have labelPositions.
getter/setter pair
- mergedWithOtherWay ↔ bool
-
This way is already merged with another way and hence should not be written to the file.
getter/setter pair
-
openOutersRead
→ List<
Waypath> -
no setter
-
openOutersWrite
→ List<
Waypath> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagholderCollection → TagholderCollection
-
final
Methods
-
clearCaches(
) → void -
cloneWith(
{List< Waypath> ? inner, List<Waypath> ? closedOuters, List<Waypath> ? openOuters}) → Wayholder -
closedOutersAdd(
Waypath waypath) → void -
closedOutersAddAll(
List< Waypath> waypaths) → void -
closedOutersIsEmpty(
) → bool -
closedOutersIsNotEmpty(
) → bool -
closedOutersLength(
) → int -
closedOutersRemove(
Waypath waypath) → void -
extractMaster(
) → Waypath -
getTag(
String key) → String? -
hasTag(
String key) → bool -
hasTagValue(
String key, String value) → bool -
innerAdd(
Waypath waypath) → void -
innerAddAll(
List< Waypath> waypaths) → void -
innerIsEmpty(
) → bool -
innerIsNotEmpty(
) → bool -
mayMoveToClosed(
Waypath waypath) → bool -
moveInnerToOuter(
) → void - moves the inner ways to the outer ways if no outer ways exists anymore
-
nodeCount(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openOutersAdd(
Waypath waypath) → void -
openOutersAddAll(
List< Waypath> waypaths) → void -
openOutersIsEmpty(
) → bool -
openOutersIsNotEmpty(
) → bool -
openOutersLength(
) → int -
openOutersRemove(
Waypath waypath) → void -
pathCount(
) → int -
toString(
) → String -
A string representation of this object.
override
-
toStringWithoutNames(
) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited