WayholderCollection class
A helper class to hold all ways for a specific zoom level during the sub-file creation process.
- Implemented types
Constructors
Properties
Methods
-
add(
Wayholder wayholder) → void -
override
-
addAll(
Iterable< Wayholder> wayholders) → void -
override
-
dispose(
) → Future< void> -
override
-
forEach(
void action(Wayholder wayholder)) → Future< void> -
override
-
freeRessources(
) → Future< void> -
Frees resources that cannot be transferred to an isolate.
override
-
nodeCount(
) → Future< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pathCount(
) → Future< int> -
override
-
removeWhere(
bool test(Wayholder wayholder)) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited